@@ -18,8 +18,8 @@ from scipy._lib._util import _rng_html_rewrite
 # Workaround for sphinx-doc/sphinx#6573
 # ua._Function should not be treated as an attribute
 import scipy._lib.uarray as ua
-from scipy.stats._distn_infrastructure import rv_generic  # noqa: E402
-from scipy.stats._multivariate import multi_rv_generic  # noqa: E402
+from scipy.stats._distn_infrastructure import rv_generic
+from scipy.stats._multivariate import multi_rv_generic
 
 
 old_isdesc = inspect.isdescriptor
@@ -38,7 +38,7 @@ os.environ['_SCIPY_BUILDING_DOC'] = 'True'
 
 sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
 
-import numpydoc.docscrape as np_docscrape  # noqa:E402
+import numpydoc.docscrape as np_docscrape  # noqa: E402
 
 extensions = [
     'sphinx.ext.autodoc',
@@ -52,6 +52,7 @@ extensions = [
     'doi_role',
     'matplotlib.sphinxext.plot_directive',
     'myst_nb',
+    'jupyterlite_sphinx',
 ]
 
 
@@ -199,20 +200,39 @@ html_theme = 'pydata_sphinx_theme'
 html_logo = '_static/logo.svg'
 html_favicon = '_static/favicon.ico'
 
+html_sidebars = {
+    "index": "search-button-field",
+    "**": ["search-button-field", "sidebar-nav-bs"]
+}
+
 html_theme_options = {
   "github_url": "https://github.com/scipy/scipy",
   "twitter_url": "https://twitter.com/SciPy_team",
-  "navbar_end": ["theme-switcher", "version-switcher", "navbar-icon-links"],
+  "header_links_before_dropdown": 6,
+  "icon_links": [],
+  "navbar_start": ["navbar-logo", "version-switcher"],
+  "navbar_persistent": [],
   "switcher": {
       "json_url": "https://scipy.github.io/devdocs/_static/version_switcher.json",
       "version_match": version,
+  },
+  "show_version_warning_banner": True,
+  "secondary_sidebar_items": ["page-toc"],
+  # The service https://plausible.io is used to gather simple
+  # and privacy-friendly analytics for the site. The dashboard can be accessed
+  # at https://analytics.scientific-python.org/docs.scipy.org
+  # The Scientific-Python community is hosting and managing the account.
+  "analytics": {
+      "plausible_analytics_domain": "docs.scipy.org",
+      "plausible_analytics_url": "https://views.scientific-python.org/js/script.js",
   }
 }
 
 if 'dev' in version:
     html_theme_options["switcher"]["version_match"] = "development"
+    html_theme_options["show_version_warning_banner"] = False
 
-if 'versionwarning' in tags:  # noqa
+if 'versionwarning' in tags:  # noqa: F821
     # Specific to docs.scipy.org deployment.
     # See https://github.com/scipy/docs.scipy.org/blob/main/_static/versionwarning.js_t
     src = ('var script = document.createElement("script");\n'
@@ -230,6 +250,7 @@ html_last_updated_fmt = '%b %d, %Y'
 
 html_css_files = [
     "scipy.css",
+    "try_examples.css",
 ]
 
 # html_additional_pages = {
@@ -285,6 +306,7 @@ autosummary_generate = True
 autosummary_filename_map = {
     "scipy.odr.odr": "odr-function",
     "scipy.signal.czt": "czt-function",
+    "scipy.signal.ShortTimeFFT.t": "scipy.signal.ShortTimeFFT.t.lower",
 }
 
 
@@ -322,18 +344,23 @@ coverage_ignore_c_items = {}
 plot_pre_code = """
 import warnings
 for key in (
-        'lsim2 is deprecated',  # Deprecation of scipy.signal.lsim2
-        'impulse2 is deprecated',  # Deprecation of scipy.signal.impulse2
-        'step2 is deprecated',  # Deprecation of scipy.signal.step2
         'interp2d` is deprecated',  # Deprecation of scipy.interpolate.interp2d
         'scipy.misc',  # scipy.misc deprecated in v1.10.0; use scipy.datasets
         'kurtosistest only valid',  # intentionally "bad" excample in docstring
+        'scipy.signal.daub is deprecated',
+        'scipy.signal.qmf is deprecated',
+        'scipy.signal.cascade is deprecated',
+        'scipy.signal.morlet is deprecated',
+        'scipy.signal.morlet2 is deprecated',
+        'scipy.signal.ricker is deprecated',
+        'scipy.signal.cwt is deprecated',
         ):
     warnings.filterwarnings(action='ignore', message='.*' + key + '.*')
 
 import numpy as np
 np.random.seed(123)
 """
+
 plot_include_source = True
 plot_formats = [('png', 96)]
 plot_html_show_formats = False
@@ -364,6 +391,22 @@ plot_rcparams = {
 # -----------------------------------------------------------------------------
 
 nb_execution_mode = "auto"
+# Ignore notebooks generated by jupyterlite-sphinx for interactive examples.
+nb_execution_excludepatterns = ["_contents/*.ipynb"]
+
+#------------------------------------------------------------------------------
+# Interactive examples with jupyterlite-sphinx
+#------------------------------------------------------------------------------
+global_enable_try_examples = True
+try_examples_global_button_text = "Try it in your browser!"
+try_examples_global_warning_text = (
+    "SciPy's interactive examples with Jupyterlite are experimental and may"
+    " not always work as expected. Execution of cells containing imports may"
+    " result in large downloads (up to 60MB of content for the first import"
+    " from SciPy). Load times when importing from SciPy may take roughly 10-20"
+    " seconds. If you notice any problems, feel free to open an"
+    " [issue](https://github.com/scipy/scipy/issues/new/choose)."
+)
 
 # -----------------------------------------------------------------------------
 # Source code links
