@@ -7,40 +7,18 @@
  *  Travis E. Oliphant
  */
 
-#ifndef _SPEC_WRAPPERS_H
-#define _SPEC_WRAPPERS_H
+#pragma once
+
 #include "Python.h"
 #include <numpy/npy_math.h>
 #include <math.h>
-
+#include "npy_2_complexcompat.h"
 #include "sf_error.h"
 
-#define REAL(z) (z).real
-#define IMAG(z) (z).imag
-#define ABSQ(z) (z).real*(z).real + (z).imag*(z).imag;
-#define ZCONVINF(func,z)                                                \
-    do {                                                                \
-        if ((double)REAL((z)) == (double)1.0e300) {                     \
-            sf_error(func, SF_ERROR_OVERFLOW, NULL);                    \
-            REAL((z)) = NPY_INFINITY;                                   \
-        }                                                               \
-        if ((double)REAL((z)) == (double)-1.0e300) {                    \
-            sf_error(func, SF_ERROR_OVERFLOW, NULL);                    \
-            REAL((z)) = -NPY_INFINITY;                                  \
-        }                                                               \
-    } while (0)
-#define CONVINF(func, x)                                                \
-    do {                                                                \
-        if ((double)(x) == (double)1.0e300) {                           \
-            sf_error(func, SF_ERROR_OVERFLOW, NULL);                    \
-            (x)=NPY_INFINITY;                                           \
-        }                                                               \
-        if ((double)(x) == (double)-1.0e300) {                          \
-            sf_error(func, SF_ERROR_OVERFLOW, NULL);                    \
-            (x)=-NPY_INFINITY;                                          \
-        }                                                               \
-    } while (0)
-#define ABS(x) ((x)<0 ? -(x) : (x))
+#ifdef __cplusplus
+extern "C"
+{
+#endif /* __cplusplus */
 
 npy_cdouble clngamma_wrap( npy_cdouble z);
 npy_cdouble chyp2f1_wrap( double a, double b, double c, npy_cdouble z);
@@ -110,16 +88,7 @@ double oblate_segv_wrap(double, double, double);
 
 int modified_fresnel_plus_wrap(double x, npy_cdouble *F, npy_cdouble *K);
 int modified_fresnel_minus_wrap(double x, npy_cdouble *F, npy_cdouble *K);
-#endif
-
-
-
-
-  
-
-
-
-
-
-
 
+#ifdef __cplusplus
+}  /* extern "C" */
+#endif /* __cplusplus */
