@@ -20,6 +20,6 @@ printenv
 cat $PROJECT_DIR/tools/wheels/LICENSE_linux.txt >> $PROJECT_DIR/LICENSE.txt
 
 # Install Openblas
-basedir=$(python tools/openblas_support.py)
+basedir=$(python tools/openblas_support.py $NIGHTLY_FLAG)
 cp -r $basedir/lib/* /usr/local/lib
 cp $basedir/include/* /usr/local/include
